'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

module.exports = yeoman.Base.extend({

  prompting: function () {
    var done = this.async();

    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the legendary ' + chalk.red('generator-frontend-webpack') + ' generator!'
    ));

    var prompts = [
      {
        type: 'input',
        name: 'projectName',
        message: 'What\'s the majestic project name?',
        default: this.appname
      },
      {
        type: 'input',
        name: 'description',
        message: 'Now give me a magnificent description',
        default: ''
      },
      {
        type: 'input',
        name: 'projectHomepage',
        message: 'What\'s the project homepage?',
        default: ''
      },
      {
        type: 'input',
        name: 'projectRepository',
        message: 'Git repository',
        default: ''
      },
      {
        type: 'input',
        name: 'authorName',
        message: 'What\'s the awesome name of the author?',
        default: '',
        store: true
      },
      {
        type: 'input',
        name: 'authorEmail',
        message: 'Author email',
        default: '',
        store: true
      },
      {
        type: 'input',
        name: 'authorHomepage',
        message: 'Author homepage',
        default: '',
        store: true
      },
      {
        type: 'input',
        name: 'license',
        message: 'License?',
        default: 'MIT'
      },
      {
        type: 'checkbox',
        name: 'libs',
        message: 'Libraries/Frameworks',
        choices: [
          'React'
        ],
        default: [
          false
        ]
      }
    ];

    this.prompt(prompts, function (props) {
      this.props = props;
      done();
    }.bind(this));
  },

  writing: function () {
    this.fs.copy(
      this.templatePath('src'),
      this.destinationPath('src')
    );
    this.fs.copy(
      this.templatePath('.editorconfig'),
      this.destinationPath('.editorconfig')
    );
    this.fs.copy(
      this.templatePath('.eslintignore'),
      this.destinationPath('.eslintignore')
    );
    this.fs.copyTpl(
      this.templatePath('.eslintrc'),
      this.destinationPath('.eslintrc'),
      {
        usingReact: this.props.libs[0]
      }
    );
    this.fs.copy(
      this.templatePath('.gitignore'),
      this.destinationPath('.gitignore')
    );
    this.fs.copy(
      this.templatePath('.tern-project'),
      this.destinationPath('.tern-project')
    );
    this.fs.copyTpl(
      this.templatePath('package.json'),
      this.destinationPath('package.json'),
      {
        projectName: this.props.projectName,
        projectRepository: this.props.projectRepository,
        authorName: this.props.authorName,
        authorEmail: this.props.authorEmail,
        authorHomepage: this.props.authorHomepage,
        description: this.props.description,
        license: this.props.license,
        usingReact: this.props.libs[0]
      }
    );
    this.fs.copyTpl(
      this.templatePath('README.md'),
      this.destinationPath('README.md'),
      {
        projectName: this.props.projectName,
        authorName: this.props.authorName,
        authorEmail: this.props.authorEmail,
        authorHomepage: this.props.authorHomepage,
        description: this.props.description,
        license: this.props.license
      }
    );
    this.fs.copy(
      this.templatePath('webpack.config.js'),
      this.destinationPath('webpack.config.js')
    );
  },

  install: function () {
    this.npmInstall();
  }
});
